<template>
  <div>
    <el-dialog
      width="60%"
      :title="titleUp + '产品类型'"
      :visible.sync="showFormDiaUp"
      :before-close="handleClose" :close-on-click-modal="false"
    >
      <el-form
        ref="formInfo"
        :rules="rules"
        :model="params"
        label-width="120px"
      >
        <el-collapse accordion v-model="activeCollapse1" class="form-collapse">
          <el-collapse-item name="1">
            <template slot="title">
              <span class="collapse-title">
                <i class="collapse-title-icon el-icon-info"></i>
                产品类型基本信息
              </span>
            </template>
            <el-row>
              <el-col :span="12">
                <el-form-item prop="code" label="分类编码">
                  <el-input
                    placeholder="请输入分类编码"
                    v-model="params.code"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="12">
                <el-form-item prop="name" label="分类名称">
                  <el-input
                    placeholder="请输入分类名称"
                    v-model="params.name"
                  ></el-input>
                </el-form-item>
              </el-col>
            </el-row>
            <el-form-item label="备注" prop="memo">
              <el-input
                type="textarea"
                :autosize="{minRows: 3, maxRows: 4}"
                placeholder="请输入备注内容"
                v-model="params.memo"
              >
              </el-input>
            </el-form-item>
          </el-collapse-item>
        </el-collapse>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import productManage from '@/api/device/productManage.js'

export default {
  name: 'FormDialog',
  props: {
    showFormDiaUp: {
      type: Boolean,
      default: false
    },
    titleUp: {
      type: String,
      default: ''
    },
    pId: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      params: {
        code: '',
        name: '',
        memo: '',
        parentId: this.pId,
        id: ''
      },
      activeCollapse1: '1',
      rules: {
        name: [
          {
            required: true,
            message: '请输入产品名称',
            trigger: 'blur'
          }
        ],
        code: [
          {
            required: true,
            message: '请输入产品编码',
            trigger: 'blur'
          }
        ]
      }
    }
  },
  created() {
    this.getDetailInfo()
  },
  methods: {
    // 根据ID查询
    getDetailInfo() {
      productManage.productTypeDetail(this.pId).then(res => {
        this.params = res
      })
    },
    handleClose() {
      this.params = {
        name: '',
        code: '',
        memo: '',
        parentId: ''
      }
      this.activeCollapse1 = '1'
      this.$emit('closeFormDiaoUp')
      this.$emit('refList')
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          if (this.titleUp === '修改') {
            productManage.updateProductType(this.params).then(response => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: this.titleUp + '成功',
                  duration: 2000
                })
                this.$emit('closeFormDiaoUp')
                this.$emit('refList')
              } else {
                this.$message.warning(response.message)
              }
            })
          }
        } else {
          return false
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
